==> haskell-unbounded-delays-0.1.1.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unbounded-delays
version:              0.1.1.1
visibility:           public
id:                   unbounded-delays-0.1.1.1-AgNQX1ma4b0EuIeeVLayGc
key:                  unbounded-delays-0.1.1.1-AgNQX1ma4b0EuIeeVLayGc
license:              BSD-3-Clause
copyright:            2011-2020 Bas van Dijk & Roel van Dijk
maintainer:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <roel@lambdacube.nl>

author:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <roel@lambdacube.nl>

homepage:             https://github.com/basvandijk/unbounded-delays
synopsis:             Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.

category:             Concurrency
abi:                  1a02a675b13596abd6571ce052e2c5aa
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout

import-dirs:          /usr/lib/ghc-9.0.1/site-local/unbounded-delays-0.1.1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/unbounded-delays-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/unbounded-delays-0.1.1.1
hs-libraries:         HSunbounded-delays-0.1.1.1-AgNQX1ma4b0EuIeeVLayGc
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock

haddock-html:         /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unbounded-delays-0.1.1.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unbounded-delays
version:              0.1.1.1
visibility:           public
id:                   unbounded-delays-0.1.1.1-KU4Jg1KyC6i76f9JqBmZ6Z
key:                  unbounded-delays-0.1.1.1-KU4Jg1KyC6i76f9JqBmZ6Z
license:              BSD-3-Clause
copyright:            2011-2020 Bas van Dijk & Roel van Dijk
maintainer:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <roel@lambdacube.nl>

author:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <roel@lambdacube.nl>

homepage:             https://github.com/basvandijk/unbounded-delays
synopsis:             Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.

category:             Concurrency
abi:                  14cdf80616d99d86d06e66befb27a012
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout

import-dirs:          /usr/lib/ghc-9.0.2/site-local/unbounded-delays-0.1.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unbounded-delays-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/unbounded-delays-0.1.1.1
hs-libraries:         HSunbounded-delays-0.1.1.1-KU4Jg1KyC6i76f9JqBmZ6Z
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock

haddock-html:         /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
